# openapi_client

OpenapiClient - the Ruby gem for the API League

API League is a Hub for World Class APIs.

This SDK is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.6.4
- Package version: 1.0.0
- Generator version: 7.8.0-SNAPSHOT
- Build package: org.openapitools.codegen.languages.RubyClientCodegen

## Installation

### Build a gem

To build the Ruby code into a gem:

```shell
gem build openapi_client.gemspec
```

Then either install the gem locally:

```shell
gem install ./openapi_client-1.0.0.gem
```

(for development, run `gem install --dev ./openapi_client-1.0.0.gem` to install the development dependencies)

or publish the gem to a gem hosting service, e.g. [RubyGems](https://rubygems.org/).

Finally add this to the Gemfile:

    gem 'openapi_client', '~> 1.0.0'

### Install from Git

If the Ruby gem is hosted at a git repository: https://github.com/ddsky/api-league-clients/tree/master/ruby/, then add the following in the Gemfile:

    gem 'openapi_client', :git => 'https://github.com/ddsky/api-league-clients/tree/master/ruby/.git'

### Include the Ruby code directly

Include the Ruby code directly using `-I` as follows:

```shell
ruby -Ilib script.rb
```

## Getting Started

Please follow the [installation](#installation) procedure and then run the following code:

```ruby
# Load the gem
require 'openapi_client'

# Setup authorization
OpenapiClient.configure do |config|
  # Configure API key authorization: apiKey
  config.api_key['apiKey'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  # config.api_key_prefix['apiKey'] = 'Bearer'

  # Configure API key authorization: headerApiKey
  config.api_key['headerApiKey'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  # config.api_key_prefix['headerApiKey'] = 'Bearer'
end

api_instance = OpenapiClient::ArtApi.new
url = 'https://upload.wikimedia.org/wikipedia/commons/3/35/Basic_human_drawing.png' # String | The URL to the image.
opts = {
  width: 200, # Integer | The maximum width of the image (default 400, max. 500).
  height: 200 # Integer | The maximum height of the image (default 400, max. 500).
}

begin
  #Image to Ascii Art by URL API
  result = api_instance.image_to_ascii_art_by_urlapi(url, opts)
  p result
rescue OpenapiClient::ApiError => e
  puts "Exception when calling ArtApi->image_to_ascii_art_by_urlapi: #{e}"
end

```

## Documentation for API Endpoints

All URIs are relative to *https://api.apileague.com*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*OpenapiClient::ArtApi* | [**image_to_ascii_art_by_urlapi**](docs/ArtApi.md#image_to_ascii_art_by_urlapi) | **GET** /convert-image-to-ascii-txt | Image to Ascii Art by URL API
*OpenapiClient::ArtApi* | [**random_poem_api**](docs/ArtApi.md#random_poem_api) | **GET** /retrieve-random-poem | Random Poem API
*OpenapiClient::BooksApi* | [**find_similar_books_api**](docs/BooksApi.md#find_similar_books_api) | **GET** /list-similar-books | Find Similar Books API
*OpenapiClient::BooksApi* | [**search_books_api**](docs/BooksApi.md#search_books_api) | **GET** /search-books | Search Books API
*OpenapiClient::FoodApi* | [**compute_nutrition_api**](docs/FoodApi.md#compute_nutrition_api) | **GET** /compute-nutrition | Compute Nutrition API
*OpenapiClient::FoodApi* | [**retrieve_recipe_information_api**](docs/FoodApi.md#retrieve_recipe_information_api) | **GET** /retrieve-recipe | Retrieve Recipe Information API
*OpenapiClient::FoodApi* | [**search_drinks_api**](docs/FoodApi.md#search_drinks_api) | **GET** /search-drinks | Search Drinks API
*OpenapiClient::FoodApi* | [**search_recipes_api**](docs/FoodApi.md#search_recipes_api) | **GET** /search-recipes | Search Recipes API
*OpenapiClient::FoodApi* | [**search_restaurants_api**](docs/FoodApi.md#search_restaurants_api) | **GET** /search-restaurants | Search Restaurants API
*OpenapiClient::HumorApi* | [**generate_nonsense_word_api**](docs/HumorApi.md#generate_nonsense_word_api) | **GET** /generate-nonsense-word | Generate Nonsense Word API
*OpenapiClient::HumorApi* | [**random_joke_api**](docs/HumorApi.md#random_joke_api) | **GET** /retrieve-random-joke | Random Joke API
*OpenapiClient::HumorApi* | [**random_meme_api**](docs/HumorApi.md#random_meme_api) | **GET** /retrieve-random-meme | Random Meme API
*OpenapiClient::HumorApi* | [**search_gifs_api**](docs/HumorApi.md#search_gifs_api) | **GET** /search-gifs | Search Gifs API
*OpenapiClient::HumorApi* | [**search_jokes_api**](docs/HumorApi.md#search_jokes_api) | **GET** /search-jokes | Search Jokes API
*OpenapiClient::HumorApi* | [**search_memes_api**](docs/HumorApi.md#search_memes_api) | **GET** /search-memes | Search Memes API
*OpenapiClient::KnowledgeApi* | [**random_quote_api**](docs/KnowledgeApi.md#random_quote_api) | **GET** /retrieve-random-quote | Random Quote API
*OpenapiClient::KnowledgeApi* | [**random_riddle_api**](docs/KnowledgeApi.md#random_riddle_api) | **GET** /retrieve-random-riddle | Random Riddle API
*OpenapiClient::KnowledgeApi* | [**random_trivia_api**](docs/KnowledgeApi.md#random_trivia_api) | **GET** /retrieve-random-trivia | Random Trivia API
*OpenapiClient::MathApi* | [**convert_units_api**](docs/MathApi.md#convert_units_api) | **GET** /convert-units | Convert Units API
*OpenapiClient::MediaApi* | [**detect_main_image_color_api**](docs/MediaApi.md#detect_main_image_color_api) | **GET** /detect-color | Detect Main Image Color API
*OpenapiClient::MediaApi* | [**rescale_image_api**](docs/MediaApi.md#rescale_image_api) | **GET** /rescale-image | Rescale Image API
*OpenapiClient::MediaApi* | [**search_icons_api**](docs/MediaApi.md#search_icons_api) | **GET** /search-icons | Search Icons API
*OpenapiClient::MediaApi* | [**search_royalty_free_images_api**](docs/MediaApi.md#search_royalty_free_images_api) | **GET** /search-images | Search Royalty Free Images API
*OpenapiClient::MediaApi* | [**vector_search_api**](docs/MediaApi.md#vector_search_api) | **GET** /search-vectors | Vector Search API
*OpenapiClient::NewsApi* | [**extract_news_api**](docs/NewsApi.md#extract_news_api) | **GET** /extract-news | Extract News API
*OpenapiClient::NewsApi* | [**search_news_api**](docs/NewsApi.md#search_news_api) | **GET** /search-news | Search News API
*OpenapiClient::NewsApi* | [**top_news_api**](docs/NewsApi.md#top_news_api) | **GET** /retrieve-top-news | Top News API
*OpenapiClient::StorageApi* | [**read_key_value_from_store_api**](docs/StorageApi.md#read_key_value_from_store_api) | **GET** /read-key-value | Read Key Value from Store API
*OpenapiClient::StorageApi* | [**store_key_value_getapi**](docs/StorageApi.md#store_key_value_getapi) | **GET** /store-key-value | Store Key Value (GET) API
*OpenapiClient::TextApi* | [**correct_spelling_api**](docs/TextApi.md#correct_spelling_api) | **GET** /correct-spelling | Correct Spelling API
*OpenapiClient::TextApi* | [**detect_gender_by_name_api**](docs/TextApi.md#detect_gender_by_name_api) | **GET** /detect-gender | Detect Gender by Name API
*OpenapiClient::TextApi* | [**detect_language_api**](docs/TextApi.md#detect_language_api) | **GET** /detect-language | Detect Language API
*OpenapiClient::TextApi* | [**detect_sentiment_api**](docs/TextApi.md#detect_sentiment_api) | **GET** /detect-sentiment | Detect Sentiment API
*OpenapiClient::TextApi* | [**extract_dates_api**](docs/TextApi.md#extract_dates_api) | **GET** /extract-dates | Extract Dates API
*OpenapiClient::TextApi* | [**extract_entities_api**](docs/TextApi.md#extract_entities_api) | **GET** /extract-entities | Extract Entities API
*OpenapiClient::TextApi* | [**list_word_synonyms_api**](docs/TextApi.md#list_word_synonyms_api) | **GET** /list-synonyms | List Word Synonyms API
*OpenapiClient::TextApi* | [**pluralize_word_api**](docs/TextApi.md#pluralize_word_api) | **GET** /pluralize-word | Pluralize Word API
*OpenapiClient::TextApi* | [**score_readability_api**](docs/TextApi.md#score_readability_api) | **GET** /score-readability | Score Readability API
*OpenapiClient::TextApi* | [**score_text_api**](docs/TextApi.md#score_text_api) | **GET** /score-text | Score Text API
*OpenapiClient::TextApi* | [**singularize_word_api**](docs/TextApi.md#singularize_word_api) | **GET** /singularize-word | Singularize Word API
*OpenapiClient::TextApi* | [**stem_text_api**](docs/TextApi.md#stem_text_api) | **GET** /stem-text | Stem Text API
*OpenapiClient::TextApi* | [**tag_part_of_speech_api**](docs/TextApi.md#tag_part_of_speech_api) | **GET** /tag-pos | Tag Part of Speech API
*OpenapiClient::WebApi* | [**extract_authors_api**](docs/WebApi.md#extract_authors_api) | **GET** /extract-authors | Extract Authors API
*OpenapiClient::WebApi* | [**extract_content_from_a_web_page_api**](docs/WebApi.md#extract_content_from_a_web_page_api) | **GET** /extract-content | Extract Content from a Web Page API
*OpenapiClient::WebApi* | [**extract_publish_date_api**](docs/WebApi.md#extract_publish_date_api) | **GET** /extract-publish-date | Extract Publish Date API
*OpenapiClient::WebApi* | [**retrieve_page_rank_api**](docs/WebApi.md#retrieve_page_rank_api) | **GET** /retrieve-page-rank | Retrieve Page Rank API
*OpenapiClient::WebApi* | [**search_web_api**](docs/WebApi.md#search_web_api) | **GET** /search-web | Search Web API
*OpenapiClient::WebApi* | [**verify_email_address_api**](docs/WebApi.md#verify_email_address_api) | **GET** /verify-email | Verify Email Address API


## Documentation for Models

 - [OpenapiClient::ComputeNutritionAPI200Response](docs/ComputeNutritionAPI200Response.md)
 - [OpenapiClient::ComputeNutritionAPI200ResponseIngredientBreakdownInner](docs/ComputeNutritionAPI200ResponseIngredientBreakdownInner.md)
 - [OpenapiClient::ComputeNutritionAPI200ResponseIngredientBreakdownInnerNutrientsInner](docs/ComputeNutritionAPI200ResponseIngredientBreakdownInnerNutrientsInner.md)
 - [OpenapiClient::ConvertUnitsAPI200Response](docs/ConvertUnitsAPI200Response.md)
 - [OpenapiClient::CorrectSpellingAPI200Response](docs/CorrectSpellingAPI200Response.md)
 - [OpenapiClient::DetectGenderByNameAPI200Response](docs/DetectGenderByNameAPI200Response.md)
 - [OpenapiClient::DetectLanguageAPI200ResponseInner](docs/DetectLanguageAPI200ResponseInner.md)
 - [OpenapiClient::DetectMainImageColorAPI200ResponseInner](docs/DetectMainImageColorAPI200ResponseInner.md)
 - [OpenapiClient::DetectSentimentAPI200Response](docs/DetectSentimentAPI200Response.md)
 - [OpenapiClient::DetectSentimentAPI200ResponseDocument](docs/DetectSentimentAPI200ResponseDocument.md)
 - [OpenapiClient::DetectSentimentAPI200ResponseSentencesInner](docs/DetectSentimentAPI200ResponseSentencesInner.md)
 - [OpenapiClient::ExtractAuthorsAPI200Response](docs/ExtractAuthorsAPI200Response.md)
 - [OpenapiClient::ExtractAuthorsAPI200ResponseAuthorsInner](docs/ExtractAuthorsAPI200ResponseAuthorsInner.md)
 - [OpenapiClient::ExtractContentFromAWebPageAPI200Response](docs/ExtractContentFromAWebPageAPI200Response.md)
 - [OpenapiClient::ExtractDatesAPI200Response](docs/ExtractDatesAPI200Response.md)
 - [OpenapiClient::ExtractDatesAPI200ResponseDatesInner](docs/ExtractDatesAPI200ResponseDatesInner.md)
 - [OpenapiClient::ExtractEntitiesAPI200Response](docs/ExtractEntitiesAPI200Response.md)
 - [OpenapiClient::ExtractEntitiesAPI200ResponseEntitiesInner](docs/ExtractEntitiesAPI200ResponseEntitiesInner.md)
 - [OpenapiClient::ExtractNewsAPI200Response](docs/ExtractNewsAPI200Response.md)
 - [OpenapiClient::ExtractNewsAPI200ResponseImagesInner](docs/ExtractNewsAPI200ResponseImagesInner.md)
 - [OpenapiClient::ExtractNewsAPI200ResponseVideosInner](docs/ExtractNewsAPI200ResponseVideosInner.md)
 - [OpenapiClient::ExtractPublishDateAPI200Response](docs/ExtractPublishDateAPI200Response.md)
 - [OpenapiClient::FindSimilarBooksAPI200Response](docs/FindSimilarBooksAPI200Response.md)
 - [OpenapiClient::GenerateNonsenseWordAPI200Response](docs/GenerateNonsenseWordAPI200Response.md)
 - [OpenapiClient::ListWordSynonymsAPI200Response](docs/ListWordSynonymsAPI200Response.md)
 - [OpenapiClient::PluralizeWordAPI200Response](docs/PluralizeWordAPI200Response.md)
 - [OpenapiClient::RandomMemeAPI200Response](docs/RandomMemeAPI200Response.md)
 - [OpenapiClient::RandomPoemAPI200Response](docs/RandomPoemAPI200Response.md)
 - [OpenapiClient::RandomQuoteAPI200Response](docs/RandomQuoteAPI200Response.md)
 - [OpenapiClient::RandomRiddleAPI200Response](docs/RandomRiddleAPI200Response.md)
 - [OpenapiClient::RandomTriviaAPI200Response](docs/RandomTriviaAPI200Response.md)
 - [OpenapiClient::ReadKeyValueFromStoreAPI200Response](docs/ReadKeyValueFromStoreAPI200Response.md)
 - [OpenapiClient::RetrievePageRankAPI200Response](docs/RetrievePageRankAPI200Response.md)
 - [OpenapiClient::RetrieveRecipeInformationAPI200Response](docs/RetrieveRecipeInformationAPI200Response.md)
 - [OpenapiClient::RetrieveRecipeInformationAPI200ResponseCredits](docs/RetrieveRecipeInformationAPI200ResponseCredits.md)
 - [OpenapiClient::RetrieveRecipeInformationAPI200ResponseDietaryProperties](docs/RetrieveRecipeInformationAPI200ResponseDietaryProperties.md)
 - [OpenapiClient::RetrieveRecipeInformationAPI200ResponseIngredientsInner](docs/RetrieveRecipeInformationAPI200ResponseIngredientsInner.md)
 - [OpenapiClient::RetrieveRecipeInformationAPI200ResponseIngredientsInnerMeasures](docs/RetrieveRecipeInformationAPI200ResponseIngredientsInnerMeasures.md)
 - [OpenapiClient::RetrieveRecipeInformationAPI200ResponseInstructionsInner](docs/RetrieveRecipeInformationAPI200ResponseInstructionsInner.md)
 - [OpenapiClient::RetrieveRecipeInformationAPI200ResponseInstructionsInnerStepsInner](docs/RetrieveRecipeInformationAPI200ResponseInstructionsInnerStepsInner.md)
 - [OpenapiClient::RetrieveRecipeInformationAPI200ResponseNutrition](docs/RetrieveRecipeInformationAPI200ResponseNutrition.md)
 - [OpenapiClient::RetrieveRecipeInformationAPI200ResponseNutritionIngredientBreakdownInner](docs/RetrieveRecipeInformationAPI200ResponseNutritionIngredientBreakdownInner.md)
 - [OpenapiClient::RetrieveRecipeInformationAPI200ResponseScores](docs/RetrieveRecipeInformationAPI200ResponseScores.md)
 - [OpenapiClient::RetrieveRecipeInformationAPI200ResponseTaste](docs/RetrieveRecipeInformationAPI200ResponseTaste.md)
 - [OpenapiClient::RetrieveRecipeInformationAPI200ResponseTimes](docs/RetrieveRecipeInformationAPI200ResponseTimes.md)
 - [OpenapiClient::ScoreReadabilityAPI200Response](docs/ScoreReadabilityAPI200Response.md)
 - [OpenapiClient::ScoreTextAPI200Response](docs/ScoreTextAPI200Response.md)
 - [OpenapiClient::ScoreTextAPI200ResponseInterestingness](docs/ScoreTextAPI200ResponseInterestingness.md)
 - [OpenapiClient::ScoreTextAPI200ResponseInterestingnessSubscores](docs/ScoreTextAPI200ResponseInterestingnessSubscores.md)
 - [OpenapiClient::ScoreTextAPI200ResponseReadability](docs/ScoreTextAPI200ResponseReadability.md)
 - [OpenapiClient::ScoreTextAPI200ResponseReadabilityMainscores](docs/ScoreTextAPI200ResponseReadabilityMainscores.md)
 - [OpenapiClient::ScoreTextAPI200ResponseReadabilitySubscores](docs/ScoreTextAPI200ResponseReadabilitySubscores.md)
 - [OpenapiClient::ScoreTextAPI200ResponseSkimmability](docs/ScoreTextAPI200ResponseSkimmability.md)
 - [OpenapiClient::ScoreTextAPI200ResponseSkimmabilityMainscores](docs/ScoreTextAPI200ResponseSkimmabilityMainscores.md)
 - [OpenapiClient::ScoreTextAPI200ResponseSkimmabilitySubscores](docs/ScoreTextAPI200ResponseSkimmabilitySubscores.md)
 - [OpenapiClient::ScoreTextAPI200ResponseStyle](docs/ScoreTextAPI200ResponseStyle.md)
 - [OpenapiClient::ScoreTextAPI200ResponseStyleSubscores](docs/ScoreTextAPI200ResponseStyleSubscores.md)
 - [OpenapiClient::SearchBooksAPI200Response](docs/SearchBooksAPI200Response.md)
 - [OpenapiClient::SearchBooksAPI200ResponseBooksInnerInner](docs/SearchBooksAPI200ResponseBooksInnerInner.md)
 - [OpenapiClient::SearchDrinksAPI200Response](docs/SearchDrinksAPI200Response.md)
 - [OpenapiClient::SearchDrinksAPI200ResponseDrinksInner](docs/SearchDrinksAPI200ResponseDrinksInner.md)
 - [OpenapiClient::SearchDrinksAPI200ResponseDrinksInnerCredits](docs/SearchDrinksAPI200ResponseDrinksInnerCredits.md)
 - [OpenapiClient::SearchDrinksAPI200ResponseDrinksInnerIngredientsInner](docs/SearchDrinksAPI200ResponseDrinksInnerIngredientsInner.md)
 - [OpenapiClient::SearchDrinksAPI200ResponseDrinksInnerIngredientsInnerMeasures](docs/SearchDrinksAPI200ResponseDrinksInnerIngredientsInnerMeasures.md)
 - [OpenapiClient::SearchDrinksAPI200ResponseDrinksInnerIngredientsInnerMeasuresMetric](docs/SearchDrinksAPI200ResponseDrinksInnerIngredientsInnerMeasuresMetric.md)
 - [OpenapiClient::SearchDrinksAPI200ResponseDrinksInnerIngredientsInnerMeasuresUs](docs/SearchDrinksAPI200ResponseDrinksInnerIngredientsInnerMeasuresUs.md)
 - [OpenapiClient::SearchDrinksAPI200ResponseDrinksInnerInstructionsInner](docs/SearchDrinksAPI200ResponseDrinksInnerInstructionsInner.md)
 - [OpenapiClient::SearchDrinksAPI200ResponseDrinksInnerInstructionsInnerStepsInner](docs/SearchDrinksAPI200ResponseDrinksInnerInstructionsInnerStepsInner.md)
 - [OpenapiClient::SearchDrinksAPI200ResponseDrinksInnerInstructionsInnerStepsInnerIngredientsInner](docs/SearchDrinksAPI200ResponseDrinksInnerInstructionsInnerStepsInnerIngredientsInner.md)
 - [OpenapiClient::SearchDrinksAPI200ResponseDrinksInnerNutrition](docs/SearchDrinksAPI200ResponseDrinksInnerNutrition.md)
 - [OpenapiClient::SearchDrinksAPI200ResponseDrinksInnerNutritionCaloricBreakdown](docs/SearchDrinksAPI200ResponseDrinksInnerNutritionCaloricBreakdown.md)
 - [OpenapiClient::SearchDrinksAPI200ResponseDrinksInnerNutritionFlavonoidsInner](docs/SearchDrinksAPI200ResponseDrinksInnerNutritionFlavonoidsInner.md)
 - [OpenapiClient::SearchDrinksAPI200ResponseDrinksInnerNutritionIngredientBreakdownInner](docs/SearchDrinksAPI200ResponseDrinksInnerNutritionIngredientBreakdownInner.md)
 - [OpenapiClient::SearchDrinksAPI200ResponseDrinksInnerNutritionIngredientBreakdownInnerNutrientsInner](docs/SearchDrinksAPI200ResponseDrinksInnerNutritionIngredientBreakdownInnerNutrientsInner.md)
 - [OpenapiClient::SearchDrinksAPI200ResponseDrinksInnerNutritionNutrientsInner](docs/SearchDrinksAPI200ResponseDrinksInnerNutritionNutrientsInner.md)
 - [OpenapiClient::SearchDrinksAPI200ResponseDrinksInnerNutritionWeightPerServing](docs/SearchDrinksAPI200ResponseDrinksInnerNutritionWeightPerServing.md)
 - [OpenapiClient::SearchGifsAPI200Response](docs/SearchGifsAPI200Response.md)
 - [OpenapiClient::SearchGifsAPI200ResponseImagesInner](docs/SearchGifsAPI200ResponseImagesInner.md)
 - [OpenapiClient::SearchIconsAPI200Response](docs/SearchIconsAPI200Response.md)
 - [OpenapiClient::SearchJokesAPI200Response](docs/SearchJokesAPI200Response.md)
 - [OpenapiClient::SearchJokesAPI200ResponseJokesInner](docs/SearchJokesAPI200ResponseJokesInner.md)
 - [OpenapiClient::SearchMemesAPI200Response](docs/SearchMemesAPI200Response.md)
 - [OpenapiClient::SearchMemesAPI200ResponseMemesInner](docs/SearchMemesAPI200ResponseMemesInner.md)
 - [OpenapiClient::SearchNewsAPI200Response](docs/SearchNewsAPI200Response.md)
 - [OpenapiClient::SearchNewsAPI200ResponseNewsInner](docs/SearchNewsAPI200ResponseNewsInner.md)
 - [OpenapiClient::SearchRecipesAPI200Response](docs/SearchRecipesAPI200Response.md)
 - [OpenapiClient::SearchRecipesAPI200ResponseRecipesInner](docs/SearchRecipesAPI200ResponseRecipesInner.md)
 - [OpenapiClient::SearchRecipesAPI200ResponseRecipesInnerNutrition](docs/SearchRecipesAPI200ResponseRecipesInnerNutrition.md)
 - [OpenapiClient::SearchRecipesAPI200ResponseRecipesInnerNutritionNutrientsInner](docs/SearchRecipesAPI200ResponseRecipesInnerNutritionNutrientsInner.md)
 - [OpenapiClient::SearchRestaurantsAPI200Response](docs/SearchRestaurantsAPI200Response.md)
 - [OpenapiClient::SearchRestaurantsAPI200ResponseRestaurantsInner](docs/SearchRestaurantsAPI200ResponseRestaurantsInner.md)
 - [OpenapiClient::SearchRestaurantsAPI200ResponseRestaurantsInnerAddress](docs/SearchRestaurantsAPI200ResponseRestaurantsInnerAddress.md)
 - [OpenapiClient::SearchRestaurantsAPI200ResponseRestaurantsInnerLocalHours](docs/SearchRestaurantsAPI200ResponseRestaurantsInnerLocalHours.md)
 - [OpenapiClient::SearchRestaurantsAPI200ResponseRestaurantsInnerLocalHoursOperational](docs/SearchRestaurantsAPI200ResponseRestaurantsInnerLocalHoursOperational.md)
 - [OpenapiClient::SearchRoyaltyFreeImagesAPI200Response](docs/SearchRoyaltyFreeImagesAPI200Response.md)
 - [OpenapiClient::SearchRoyaltyFreeImagesAPI200ResponseImagesInner](docs/SearchRoyaltyFreeImagesAPI200ResponseImagesInner.md)
 - [OpenapiClient::SearchRoyaltyFreeImagesAPI200ResponseImagesInnerLicense](docs/SearchRoyaltyFreeImagesAPI200ResponseImagesInnerLicense.md)
 - [OpenapiClient::SearchWebAPI200Response](docs/SearchWebAPI200Response.md)
 - [OpenapiClient::SearchWebAPI200ResponseResultsInner](docs/SearchWebAPI200ResponseResultsInner.md)
 - [OpenapiClient::SingularizeWordAPI200Response](docs/SingularizeWordAPI200Response.md)
 - [OpenapiClient::StemTextAPI200Response](docs/StemTextAPI200Response.md)
 - [OpenapiClient::StoreKeyValueGETAPI200Response](docs/StoreKeyValueGETAPI200Response.md)
 - [OpenapiClient::TagPartOfSpeechAPI200Response](docs/TagPartOfSpeechAPI200Response.md)
 - [OpenapiClient::TopNewsAPI200Response](docs/TopNewsAPI200Response.md)
 - [OpenapiClient::TopNewsAPI200ResponseTopNewsInner](docs/TopNewsAPI200ResponseTopNewsInner.md)
 - [OpenapiClient::TopNewsAPI200ResponseTopNewsInnerNewsInner](docs/TopNewsAPI200ResponseTopNewsInnerNewsInner.md)
 - [OpenapiClient::VectorSearchAPI200Response](docs/VectorSearchAPI200Response.md)
 - [OpenapiClient::VectorSearchAPI200ResponseVectorsInner](docs/VectorSearchAPI200ResponseVectorsInner.md)
 - [OpenapiClient::VerifyEmailAddressAPI200Response](docs/VerifyEmailAddressAPI200Response.md)


## Documentation for Authorization


Authentication schemes defined for the API:
### apiKey


- **Type**: API key
- **API key parameter name**: api-key
- **Location**: URL query string

### headerApiKey


- **Type**: API key
- **API key parameter name**: x-api-key
- **Location**: HTTP header

